@@ -12,20 +12,20 @@ import os.path
 import posixpath
 import re
 import sys
-
-from typing import Callable, Iterable
+from collections.abc import Iterable
+from typing import Callable
 
 from coverage import env
 from coverage.exceptions import ConfigError
 from coverage.misc import human_sorted, isolate_module, join_regex
 
-
 os = isolate_module(os)
 
 
 RELATIVE_DIR: str = ""
 CANONICAL_FILENAME_CACHE: dict[str, str] = {}
 
+
 def set_relative_directory() -> None:
     """Set the directory that `relative_filename` will be relative to."""
     global RELATIVE_DIR, CANONICAL_FILENAME_CACHE
@@ -58,7 +58,7 @@ def relative_filename(filename: str) -> str:
     """
     fnorm = os.path.normcase(filename)
     if fnorm.startswith(RELATIVE_DIR):
-        filename = filename[len(RELATIVE_DIR):]
+        filename = filename[len(RELATIVE_DIR) :]
     return filename
 
 
@@ -73,7 +73,7 @@ def canonical_filename(filename: str) -> str:
         if not os.path.isabs(filename):
             for path in [os.curdir] + sys.path:
                 if path is None:
-                    continue # type: ignore[unreachable]
+                    continue  # type: ignore[unreachable]
                 f = os.path.join(path, filename)
                 try:
                     exists = os.path.exists(f)
@@ -87,8 +87,6 @@ def canonical_filename(filename: str) -> str:
     return CANONICAL_FILENAME_CACHE[filename]
 
 
-MAX_FLAT = 100
-
 def flat_rootname(filename: str) -> str:
     """A base for a flat file name to correspond to this file.
 
@@ -101,7 +99,11 @@ def flat_rootname(filename: str) -> str:
     """
     dirname, basename = ntpath.split(filename)
     if dirname:
-        fp = hashlib.new("sha3_256", dirname.encode("UTF-8")).hexdigest()[:16]
+        fp = hashlib.new(
+            "sha3_256",
+            dirname.encode("UTF-8"),
+            usedforsecurity=False,
+        ).hexdigest()[:16]
         prefix = f"z_{fp}_"
     else:
         prefix = ""
@@ -109,7 +111,6 @@ def flat_rootname(filename: str) -> str:
 
 
 if env.WINDOWS:
-
     _ACTUAL_PATH_CACHE: dict[str, str] = {}
     _ACTUAL_PATH_LIST_CACHE: dict[str, list[str]] = {}
 
@@ -146,6 +147,7 @@ if env.WINDOWS:
         return actpath
 
 else:
+
     def actual_path(path: str) -> str:
         """The actual path for non-Windows platforms."""
         return path
@@ -163,7 +165,7 @@ def zip_location(filename: str) -> tuple[str, str] | None:
     name is in the zipfile.
 
     """
-    for ext in [".zip", ".whl", ".egg", ".pex"]:
+    for ext in [".zip", ".whl", ".egg", ".pex", ".par"]:
         zipbase, extension, inner = filename.partition(ext + sep(filename))
         if extension:
             zipfile = zipbase + ext
@@ -187,9 +189,7 @@ def source_exists(path: str) -> bool:
 
 def python_reported_file(filename: str) -> str:
     """Return the string as Python would describe this file name."""
-    if env.PYBEHAVIOR.report_absolute_files:
-        filename = os.path.abspath(filename)
-    return filename
+    return os.path.abspath(filename)
 
 
 def isabs_anywhere(filename: str) -> bool:
@@ -223,9 +223,9 @@ class TreeMatcher:
     somewhere in a subtree rooted at one of the directories.
 
     """
+
     def __init__(self, paths: Iterable[str], name: str = "unknown") -> None:
         self.original_paths: list[str] = human_sorted(paths)
-        #self.paths = list(map(os.path.normcase, paths))
         self.paths = [os.path.normcase(p) for p in paths]
         self.name = name
 
@@ -252,7 +252,8 @@ class TreeMatcher:
 
 class ModuleMatcher:
     """A matcher for modules in a tree."""
-    def __init__(self, module_names: Iterable[str], name:str = "unknown") -> None:
+
+    def __init__(self, module_names: Iterable[str], name: str = "unknown") -> None:
         self.modules = list(module_names)
         self.name = name
 
@@ -281,6 +282,7 @@ class ModuleMatcher:
 
 class GlobMatcher:
     """A matcher for files by file name pattern."""
+
     def __init__(self, pats: Iterable[str], name: str = "unknown") -> None:
         self.pats = list(pats)
         self.re = globs_to_regex(self.pats, case_insensitive=env.WINDOWS)
@@ -309,6 +311,7 @@ def sep(s: str) -> str:
 
 # Tokenizer for _glob_to_regex.
 # None as a sub means disallowed.
+# fmt: off
 G2RX_TOKENS = [(re.compile(rx), sub) for rx, sub in [
     (r"\*\*\*+", None),             # Can't have ***
     (r"[^/]+\*\*+", None),          # Can't have x**
@@ -325,17 +328,19 @@ G2RX_TOKENS = [(re.compile(rx), sub) for rx, sub in [
     (r"[\[\]]", None),              # Can't have single square brackets
     (r".", r"\\\g<0>"),             # Anything else is escaped to be safe
 ]]
+# fmt: on
+
 
 def _glob_to_regex(pattern: str) -> str:
     """Convert a file-path glob pattern into a regex."""
     # Turn all backslashes into slashes to simplify the tokenizer.
     pattern = pattern.replace("\\", "/")
     if "/" not in pattern:
-        pattern = "**/" + pattern
+        pattern = f"**/{pattern}"
     path_rx = []
     pos = 0
     while pos < len(pattern):
-        for rx, sub in G2RX_TOKENS:                     # pragma: always breaks
+        for rx, sub in G2RX_TOKENS:  # pragma: always breaks
             if m := rx.match(pattern, pos=pos):
                 if sub is None:
                     raise ConfigError(f"File pattern can't include {m[0]!r}")
@@ -371,7 +376,7 @@ def globs_to_regex(
         flags |= re.IGNORECASE
     rx = join_regex(map(_glob_to_regex, patterns))
     if not partial:
-        rx = fr"(?:{rx})\Z"
+        rx = rf"(?:{rx})\Z"
     compiled = re.compile(rx, flags=flags)
     return compiled
 
@@ -387,6 +392,7 @@ class PathAliases:
     map a path through those aliases to produce a unified path.
 
     """
+
     def __init__(
         self,
         debugfn: Callable[[str], None] | None = None,
@@ -443,7 +449,7 @@ class PathAliases:
         result = result.rstrip(r"\/") + result_sep
         self.aliases.append((original_pattern, regex, result))
 
-    def map(self, path: str, exists:Callable[[str], bool] = source_exists) -> str:
+    def map(self, path: str, exists: Callable[[str], bool] = source_exists) -> str:
         """Map `path` through the aliases.
 
         `path` is checked against all of the patterns.  The first pattern to
@@ -477,13 +483,13 @@ class PathAliases:
                     new = new[2:]
                 if not exists(new):
                     self.debugfn(
-                        f"Rule {original_pattern!r} changed {path!r} to {new!r} " +
-                        "which doesn't exist, continuing",
+                        f"Rule {original_pattern!r} changed {path!r} to {new!r} "
+                        + "which doesn't exist, continuing",
                     )
                     continue
                 self.debugfn(
-                    f"Matched path {path!r} to rule {original_pattern!r} -> {result!r}, " +
-                    f"producing {new!r}",
+                    f"Matched path {path!r} to rule {original_pattern!r} -> {result!r}, "
+                    + f"producing {new!r}",
                 )
                 return new
 
@@ -498,7 +504,7 @@ class PathAliases:
             if len(parts) > 1:
                 dir1 = parts[0]
                 pattern = f"*/{dir1}"
-                regex_pat = fr"^(.*[\\/])?{re.escape(dir1)}[\\/]"
+                regex_pat = rf"^(.*[\\/])?{re.escape(dir1)}[\\/]"
                 result = f"{dir1}{os.sep}"
                 # Only add a new pattern if we don't already have this pattern.
                 if not any(p == pattern for p, _, _ in self.aliases):
