@@ -114,10 +114,11 @@ register your dynamic context switcher.
 
 from __future__ import annotations
 
+import dataclasses
 import functools
-
+from collections.abc import Iterable
 from types import FrameType
-from typing import Any, Dict, Iterable, Optional, Set, Tuple, Union
+from typing import Any
 
 from coverage import files
 from coverage.misc import _needs_to_implement
@@ -130,7 +131,7 @@ class CoveragePlugin:
     _coverage_plugin_name: str
     _coverage_enabled: bool
 
-    def file_tracer(self, filename: str) -> Optional[FileTracer]: # pylint: disable=unused-argument
+    def file_tracer(self, filename: str) -> FileTracer | None:  # pylint: disable=unused-argument
         """Get a :class:`FileTracer` object for a file.
 
         Plug-in type: file tracer.
@@ -170,10 +171,10 @@ class CoveragePlugin:
         """
         return None
 
-    def file_reporter(                  # type: ignore[return]
+    def file_reporter(
         self,
-        filename: str,                  # pylint: disable=unused-argument
-    ) -> Union[FileReporter, str]:      # str should be Literal["python"]
+        filename: str,  # pylint: disable=unused-argument
+    ) -> FileReporter | str:  # str should be Literal["python"]
         """Get the :class:`FileReporter` class to use for a file.
 
         Plug-in type: file tracer.
@@ -189,8 +190,8 @@ class CoveragePlugin:
 
     def dynamic_context(
         self,
-        frame: FrameType,               # pylint: disable=unused-argument
-    ) -> Optional[str]:
+        frame: FrameType,  # pylint: disable=unused-argument
+    ) -> str | None:
         """Get the dynamically computed context label for `frame`.
 
         Plug-in type: dynamic context.
@@ -208,7 +209,7 @@ class CoveragePlugin:
 
     def find_executable_files(
         self,
-        src_dir: str,                   # pylint: disable=unused-argument
+        src_dir: str,  # pylint: disable=unused-argument
     ) -> Iterable[str]:
         """Yield all of the executable files in `src_dir`, recursively.
 
@@ -238,7 +239,7 @@ class CoveragePlugin:
         """
         pass
 
-    def sys_info(self) -> Iterable[Tuple[str, Any]]:
+    def sys_info(self) -> Iterable[tuple[str, Any]]:
         """Get a list of information useful for debugging.
 
         Plug-in type: any.
@@ -254,6 +255,7 @@ class CoveragePlugin:
 
 class CoveragePluginBase:
     """Plugins produce specialized objects, which point back to the original plugin."""
+
     _coverage_plugin: CoveragePlugin
 
 
@@ -274,7 +276,7 @@ class FileTracer(CoveragePluginBase):
 
     """
 
-    def source_filename(self) -> str:       # type: ignore[return]
+    def source_filename(self) -> str:
         """The source file name for this file.
 
         This may be any file name you like.  A key responsibility of a plug-in
@@ -309,9 +311,9 @@ class FileTracer(CoveragePluginBase):
 
     def dynamic_source_filename(
         self,
-        filename: str,                  # pylint: disable=unused-argument
-        frame: FrameType,               # pylint: disable=unused-argument
-    ) -> Optional[str]:
+        filename: str,  # pylint: disable=unused-argument
+        frame: FrameType,  # pylint: disable=unused-argument
+    ) -> str | None:
         """Get a dynamically computed source file name.
 
         Some plug-ins need to compute the source file name dynamically for each
@@ -326,7 +328,7 @@ class FileTracer(CoveragePluginBase):
         """
         return None
 
-    def line_number_range(self, frame: FrameType) -> Tuple[TLineNo, TLineNo]:
+    def line_number_range(self, frame: FrameType) -> tuple[TLineNo, TLineNo]:
         """Get the range of source line numbers for a given a call frame.
 
         The call frame is examined, and the source line number in the original
@@ -344,6 +346,35 @@ class FileTracer(CoveragePluginBase):
         return lineno, lineno
 
 
+@dataclasses.dataclass
+class CodeRegion:
+    """Data for a region of code found by :meth:`FileReporter.code_regions`."""
+
+    #: The kind of region, like `"function"` or `"class"`. Must be one of the
+    #: singular values returned by :meth:`FileReporter.code_region_kinds`.
+    kind: str
+
+    #: The name of the region. For example, a function or class name.
+    name: str
+
+    #: The line in the source file to link to when navigating to the region.
+    #: Can be a line not mentioned in `lines`.
+    start: int
+
+    #: The lines in the region. Should be lines that could be executed in the
+    #: region.  For example, a class region includes all of the lines in the
+    #: methods of the class, but not the lines defining class attributes, since
+    #: they are executed on import, not as part of exercising the class.  The
+    #: set can include non-executable lines like blanks and comments.
+    lines: set[int]
+
+    def __lt__(self, other: CodeRegion) -> bool:
+        """To support sorting to make test-writing easier."""
+        if self.name == other.name:
+            return min(self.lines) < min(other.lines)
+        return self.name < other.name
+
+
 @functools.total_ordering
 class FileReporter(CoveragePluginBase):
     """Support needed for files during the analysis and reporting phases.
@@ -369,7 +400,7 @@ class FileReporter(CoveragePluginBase):
         self.filename = filename
 
     def __repr__(self) -> str:
-        return "<{0.__class__.__name__} filename={0.filename!r}>".format(self)
+        return f"<{self.__class__.__name__} filename={self.filename!r}>"
 
     def relative_filename(self) -> str:
         """Get the relative file name for this file.
@@ -395,7 +426,7 @@ class FileReporter(CoveragePluginBase):
         with open(self.filename, encoding="utf-8") as f:
             return f.read()
 
-    def lines(self) -> Set[TLineNo]:    # type: ignore[return]
+    def lines(self) -> set[TLineNo]:
         """Get the executable lines in this file.
 
         Your plug-in must determine which lines in the file were possibly
@@ -406,7 +437,7 @@ class FileReporter(CoveragePluginBase):
         """
         _needs_to_implement(self, "lines")
 
-    def excluded_lines(self) -> Set[TLineNo]:
+    def excluded_lines(self) -> set[TLineNo]:
         """Get the excluded executable lines in this file.
 
         Your plug-in can use any method it likes to allow the user to exclude
@@ -419,7 +450,7 @@ class FileReporter(CoveragePluginBase):
         """
         return set()
 
-    def translate_lines(self, lines: Iterable[TLineNo]) -> Set[TLineNo]:
+    def translate_lines(self, lines: Iterable[TLineNo]) -> set[TLineNo]:
         """Translate recorded lines into reported lines.
 
         Some file formats will want to report lines slightly differently than
@@ -439,7 +470,7 @@ class FileReporter(CoveragePluginBase):
         """
         return set(lines)
 
-    def arcs(self) -> Set[TArc]:
+    def arcs(self) -> set[TArc]:
         """Get the executable arcs in this file.
 
         To support branch coverage, your plug-in needs to be able to indicate
@@ -453,7 +484,7 @@ class FileReporter(CoveragePluginBase):
         """
         return set()
 
-    def no_branch_lines(self) -> Set[TLineNo]:
+    def no_branch_lines(self) -> set[TLineNo]:
         """Get the lines excused from branch coverage in this file.
 
         Your plug-in can use any method it likes to allow the user to exclude
@@ -466,7 +497,7 @@ class FileReporter(CoveragePluginBase):
         """
         return set()
 
-    def translate_arcs(self, arcs: Iterable[TArc]) -> Set[TArc]:
+    def translate_arcs(self, arcs: Iterable[TArc]) -> set[TArc]:
         """Translate recorded arcs into reported arcs.
 
         Similar to :meth:`translate_lines`, but for arcs.  `arcs` is a set of
@@ -479,7 +510,7 @@ class FileReporter(CoveragePluginBase):
         """
         return set(arcs)
 
-    def exit_counts(self) -> Dict[TLineNo, int]:
+    def exit_counts(self) -> dict[TLineNo, int]:
         """Get a count of exits from that each line.
 
         To determine which lines are branches, coverage.py looks for lines that
@@ -496,7 +527,7 @@ class FileReporter(CoveragePluginBase):
         self,
         start: TLineNo,
         end: TLineNo,
-        executed_arcs: Optional[Iterable[TArc]] = None,     # pylint: disable=unused-argument
+        executed_arcs: Iterable[TArc] | None = None,  # pylint: disable=unused-argument
     ) -> str:
         """Provide an English sentence describing a missing arc.
 
@@ -512,6 +543,14 @@ class FileReporter(CoveragePluginBase):
         """
         return f"Line {start} didn't jump to line {end}"
 
+    def arc_description(
+        self,
+        start: TLineNo,  # pylint: disable=unused-argument
+        end: TLineNo,
+    ) -> str:
+        """Provide an English description of an arc's effect."""
+        return f"jump to line {end}"
+
     def source_token_lines(self) -> TSourceTokenLines:
         """Generate a series of tokenized lines, one for each line in `source`.
 
@@ -543,6 +582,31 @@ class FileReporter(CoveragePluginBase):
         for line in self.source().splitlines():
             yield [("txt", line)]
 
+    def code_regions(self) -> Iterable[CodeRegion]:
+        """Identify regions in the source file for finer reporting than by file.
+
+        Returns an iterable of :class:`CodeRegion` objects.  The kinds reported
+        should be in the possibilities returned by :meth:`code_region_kinds`.
+
+        """
+        return []
+
+    def code_region_kinds(self) -> Iterable[tuple[str, str]]:
+        """Return the kinds of code regions this plugin can find.
+
+        The returned pairs are the singular and plural forms of the kinds::
+
+            [
+                ("function", "functions"),
+                ("class", "classes"),
+            ]
+
+        This will usually be hard-coded, but could also differ by the specific
+        source file involved.
+
+        """
+        return []
+
     def __eq__(self, other: Any) -> bool:
         return isinstance(other, FileReporter) and self.filename == other.filename
 
@@ -550,4 +614,4 @@ class FileReporter(CoveragePluginBase):
         return isinstance(other, FileReporter) and self.filename < other.filename
 
     # This object doesn't need to be hashed.
-    __hash__ = None         # type: ignore[assignment]
+    __hash__ = None  # type: ignore[assignment]
