@@ -7,6 +7,7 @@ import os, sys
 
 nest = 0
 
+
 def trace(frame, event, arg):
     global nest
 
@@ -14,24 +15,30 @@ def trace(frame, event, arg):
         # This can happen when Python is shutting down.
         return None
 
-    print("%s%s %s %d @%d" % (
-        "    " * nest,
-        event,
-        os.path.basename(frame.f_code.co_filename),
-        frame.f_lineno,
-        frame.f_lasti,
-        ))
+    if the_program in frame.f_code.co_filename:
+        print(
+            "%s%s %s %d @%d"
+            % (
+                "    " * nest,
+                event,
+                os.path.basename(frame.f_code.co_filename),
+                frame.f_lineno,
+                frame.f_lasti,
+            )
+        )
 
-    if event == 'call':
+    if event == "call":
         nest += 1
-    if event == 'return':
+    if event == "return":
         nest -= 1
 
     return trace
 
+
 print(sys.version)
 the_program = sys.argv[1]
 
-code = open(the_program).read()
+code = open(the_program, encoding="utf-8").read()
+code_obj = compile(code, the_program, mode="exec")
 sys.settrace(trace)
-exec(code)
+exec(code_obj)
