@@ -8,14 +8,17 @@ from __future__ import annotations
 import inspect
 import os.path
 
-from typing import Any, List, Optional, Tuple
+from typing import Any
 from unittest import mock
 
+import pytest
+
 import coverage
 from coverage.context import qualname_from_frame
 from coverage.data import CoverageData, sorted_lines
 from coverage.types import TArc, TCovKwargs, TLineNo
 
+from tests import testenv
 from tests.coveragetest import CoverageTest
 from tests.helpers import assert_count_equal
 
@@ -45,9 +48,8 @@ class StaticContextTest(CoverageTest):
         """
 
     LINES = [1, 2, 4]
-    ARCS = [(-1, 1), (1, 2), (2, 4), (4, -1)]
 
-    def run_red_blue(self, **options: TCovKwargs) -> Tuple[CoverageData, CoverageData]:
+    def run_red_blue(self, **options: TCovKwargs) -> tuple[CoverageData, CoverageData]:
         """Run red.py and blue.py, and return their CoverageData objects."""
         self.make_file("red.py", self.SOURCE)
         red_cov = coverage.Coverage(context="red", data_suffix="r", source=["."], **options)
@@ -70,60 +72,69 @@ class StaticContextTest(CoverageTest):
             for data in datas:
                 combined.update(data)
 
-            assert combined.measured_contexts() == {'red', 'blue'}
+            assert combined.measured_contexts() == {"red", "blue"}
 
             full_names = {os.path.basename(f): f for f in combined.measured_files()}
-            assert_count_equal(full_names, ['red.py', 'blue.py'])
+            assert_count_equal(full_names, ["red.py", "blue.py"])
 
-            fred = full_names['red.py']
-            fblue = full_names['blue.py']
+            fred = full_names["red.py"]
+            fblue = full_names["blue.py"]
 
-            def assert_combined_lines(filename: str, context: str, lines: List[TLineNo]) -> None:
+            def assert_combined_lines(filename: str, context: str, lines: list[TLineNo]) -> None:
                 # pylint: disable=cell-var-from-loop
                 combined.set_query_context(context)
                 assert combined.lines(filename) == lines
 
-            assert_combined_lines(fred, 'red', self.LINES)
-            assert_combined_lines(fred, 'blue', [])
-            assert_combined_lines(fblue, 'red', [])
-            assert_combined_lines(fblue, 'blue', self.LINES)
+            assert_combined_lines(fred, "red", self.LINES)
+            assert_combined_lines(fred, "blue", [])
+            assert_combined_lines(fblue, "red", [])
+            assert_combined_lines(fblue, "blue", self.LINES)
 
     def test_combining_arc_contexts(self) -> None:
         red_data, blue_data = self.run_red_blue(branch=True)
+
+        # The exact arc data changes depending on the core and the version.
+        # Extract the red arc data for comparisons below.
+        arc_data = red_data.arcs(
+            next(fname for fname in red_data.measured_files() if "red.py" in fname)
+        )
+        assert arc_data is not None
+
         for datas in [[red_data, blue_data], [blue_data, red_data]]:
             combined = CoverageData(suffix="combined")
             for data in datas:
                 combined.update(data)
 
-            assert combined.measured_contexts() == {'red', 'blue'}
+            assert combined.measured_contexts() == {"red", "blue"}
 
             full_names = {os.path.basename(f): f for f in combined.measured_files()}
-            assert_count_equal(full_names, ['red.py', 'blue.py'])
+            assert_count_equal(full_names, ["red.py", "blue.py"])
 
-            fred = full_names['red.py']
-            fblue = full_names['blue.py']
+            fred = full_names["red.py"]
+            fblue = full_names["blue.py"]
 
-            def assert_combined_lines(filename: str, context: str, lines: List[TLineNo]) -> None:
+            def assert_combined_lines(filename: str, context: str, lines: list[TLineNo]) -> None:
                 # pylint: disable=cell-var-from-loop
                 combined.set_query_context(context)
                 assert combined.lines(filename) == lines
 
-            assert_combined_lines(fred, 'red', self.LINES)
-            assert_combined_lines(fred, 'blue', [])
-            assert_combined_lines(fblue, 'red', [])
-            assert_combined_lines(fblue, 'blue', self.LINES)
+            assert_combined_lines(fred, "red", self.LINES)
+            assert_combined_lines(fred, "blue", [])
+            assert_combined_lines(fblue, "red", [])
+            assert_combined_lines(fblue, "blue", self.LINES)
 
-            def assert_combined_arcs(filename: str, context: str, lines: List[TArc]) -> None:
+            def assert_combined_arcs(filename: str, context: str, lines: list[TArc]) -> None:
                 # pylint: disable=cell-var-from-loop
                 combined.set_query_context(context)
                 assert combined.arcs(filename) == lines
 
-            assert_combined_arcs(fred, 'red', self.ARCS)
-            assert_combined_arcs(fred, 'blue', [])
-            assert_combined_arcs(fblue, 'red', [])
-            assert_combined_arcs(fblue, 'blue', self.ARCS)
+            assert_combined_arcs(fred, "red", arc_data)
+            assert_combined_arcs(fred, "blue", [])
+            assert_combined_arcs(fblue, "red", [])
+            assert_combined_arcs(fblue, "blue", arc_data)
 
 
+@pytest.mark.skipif(not testenv.DYN_CONTEXTS, reason="No dynamic contexts with this core")
 class DynamicContextTest(CoverageTest):
     """Tests of dynamically changing contexts."""
 
@@ -165,10 +176,10 @@ class DynamicContextTest(CoverageTest):
         fname = full_names["two_tests.py"]
         assert_count_equal(
             data.measured_contexts(),
-            ["", "two_tests.test_one", "two_tests.test_two"]
+            ["", "two_tests.test_one", "two_tests.test_two"],
         )
 
-        def assert_context_lines(context: str, lines: List[TLineNo]) -> None:
+        def assert_context_lines(context: str, lines: list[TLineNo]) -> None:
             data.set_query_context(context)
             assert_count_equal(lines, sorted_lines(data, fname))
 
@@ -187,10 +198,10 @@ class DynamicContextTest(CoverageTest):
         fname = full_names["two_tests.py"]
         assert_count_equal(
             data.measured_contexts(),
-            ["stat", "stat|two_tests.test_one", "stat|two_tests.test_two"]
+            ["stat", "stat|two_tests.test_one", "stat|two_tests.test_two"],
         )
 
-        def assert_context_lines(context: str, lines: List[TLineNo]) -> None:
+        def assert_context_lines(context: str, lines: list[TLineNo]) -> None:
             data.set_query_context(context)
             assert_count_equal(lines, sorted_lines(data, fname))
 
@@ -199,47 +210,57 @@ class DynamicContextTest(CoverageTest):
         assert_context_lines("stat|two_tests.test_two", self.TEST_TWO_LINES)
 
 
-def get_qualname() -> Optional[str]:
+def get_qualname() -> str | None:
     """Helper to return qualname_from_frame for the caller."""
     stack = inspect.stack()[1:]
     if any(sinfo[0].f_code.co_name == "get_qualname" for sinfo in stack):
         # We're calling ourselves recursively, maybe because we're testing
         # properties. Return an int to try to get back on track.
-        return 17       # type: ignore[return-value]
+        return 17  # type: ignore[return-value]
     caller_frame = stack[0][0]
     return qualname_from_frame(caller_frame)
 
+
 # pylint: disable=missing-class-docstring, missing-function-docstring, unused-argument
 
+
 class Parent:
-    def meth(self) -> Optional[str]:
+    def meth(self) -> str | None:
         return get_qualname()
 
     @property
-    def a_property(self) -> Optional[str]:
+    def a_property(self) -> str | None:
         return get_qualname()
 
+
 class Child(Parent):
     pass
 
+
 class SomethingElse:
     pass
 
+
 class MultiChild(SomethingElse, Child):
     pass
 
-def no_arguments() -> Optional[str]:
+
+def no_arguments() -> str | None:
     return get_qualname()
 
-def plain_old_function(a: Any, b: Any) -> Optional[str]:
+
+def plain_old_function(a: Any, b: Any) -> str | None:
     return get_qualname()
 
-def fake_out(self: Any) -> Optional[str]:
+
+def fake_out(self: Any) -> str | None:
     return get_qualname()
 
-def patch_meth(self: Any) -> Optional[str]:
+
+def patch_meth(self: Any) -> str | None:
     return get_qualname()
 
+
 # pylint: enable=missing-class-docstring, missing-function-docstring, unused-argument
 
 
@@ -274,12 +295,12 @@ class QualnameTest(CoverageTest):
 
     def test_changeling(self) -> None:
         c = Child()
-        c.meth = patch_meth                                     # type: ignore[assignment]
-        assert c.meth(c) == "tests.test_context.patch_meth"     # type: ignore[call-arg]
+        c.meth = patch_meth  # type: ignore[assignment]
+        assert c.meth(c) == "tests.test_context.patch_meth"  # type: ignore[call-arg]
 
     def test_bug_829(self) -> None:
         # A class with a name like a function shouldn't confuse qualname_from_frame.
-        class test_something:               # pylint: disable=unused-variable
+        class test_something:  # pylint: disable=unused-variable
             assert get_qualname() is None
 
     def test_bug_1210(self) -> None:
