@@ -7,6 +7,7 @@ from __future__ import annotations
 
 import os.path
 import re
+import sys
 import textwrap
 import warnings
 
@@ -27,11 +28,19 @@ def foo():
 """
 
 SIMPLE_TOKENS = [
-    [('com', "# yay!")],
-    [('key', 'def'), ('ws', ' '), ('nam', 'foo'), ('op', '('), ('op', ')'), ('op', ':')],
-    [('ws', '  '), ('nam', 'say'), ('op', '('),
-        ('str', "'two = %d'"), ('ws', ' '), ('op', '%'),
-        ('ws', ' '), ('num', '2'), ('op', ')')],
+    [("com", "# yay!")],
+    [("key", "def"), ("ws", " "), ("nam", "foo"), ("op", "("), ("op", ")"), ("op", ":")],
+    [
+        ("ws", "  "),
+        ("nam", "say"),
+        ("op", "("),
+        ("str", "'two = %d'"),
+        ("ws", " "),
+        ("op", "%"),
+        ("ws", " "),
+        ("num", "2"),
+        ("op", ")"),
+    ],
 ]
 
 # Mixed-white-space program, and its token stream.
@@ -42,9 +51,9 @@ def hello():
 """
 
 MIXED_WS_TOKENS = [
-    [('key', 'def'), ('ws', ' '), ('nam', 'hello'), ('op', '('), ('op', ')'), ('op', ':')],
-    [('ws', '        '), ('nam', 'a'), ('op', '='), ('str', '"Hello world!"')],
-    [('ws', '        '), ('nam', 'b'), ('op', '='), ('str', '"indented"')],
+    [("key", "def"), ("ws", " "), ("nam", "hello"), ("op", "("), ("op", ")"), ("op", ":")],
+    [("ws", "        "), ("nam", "a"), ("op", "="), ("str", '"Hello world!"')],
+    [("ws", "        "), ("nam", "b"), ("op", "="), ("str", '"indented"')],
 ]
 
 # https://github.com/nedbat/coveragepy/issues/822
@@ -55,6 +64,7 @@ array = [ 1,2,3,4,       # 4 numbers \\
 print( "Message 2" )
 """
 
+
 class PhysTokensTest(CoverageTest):
     """Tests for coverage.py's improved tokenizer."""
 
@@ -68,7 +78,7 @@ class PhysTokensTest(CoverageTest):
             tokenized += text + "\n"
         # source_token_lines doesn't preserve trailing spaces, so trim all that
         # before comparing.
-        source = source.replace('\r\n', '\n')
+        source = source.replace("\r\n", "\n")
         source = re.sub(r"(?m)[ \t]+$", "", source)
         tokenized = re.sub(r"(?m)[ \t]+$", "", tokenized)
         assert source == tokenized
@@ -97,10 +107,43 @@ class PhysTokensTest(CoverageTest):
         real_file = os.path.join(TESTS_DIR, "test_coverage.py")
         self.check_file_tokenization(real_file)
 
-    @pytest.mark.parametrize("fname", [
-        "stress_phystoken.tok",
-        "stress_phystoken_dos.tok",
-    ])
+    def test_1828(self) -> None:
+        # https://github.com/nedbat/coveragepy/pull/1828
+        tokens = list(
+            source_token_lines(
+                textwrap.dedent("""
+            x = \
+                1
+            a = ["aaa",\\
+                 "bbb \\
+                 ccc"]
+            """)
+            )
+        )
+        assert tokens == [
+            [],
+            [("nam", "x"), ("ws", " "), ("op", "="), ("ws", "                 "), ("num", "1")],
+            [
+                ("nam", "a"),
+                ("ws", " "),
+                ("op", "="),
+                ("ws", " "),
+                ("op", "["),
+                ("str", '"aaa"'),
+                ("op", ","),
+                ("xx", "\\"),
+            ],
+            [("ws", "     "), ("str", '"bbb \\')],
+            [("str", '     ccc"'), ("op", "]")],
+        ]
+
+    @pytest.mark.parametrize(
+        "fname",
+        [
+            "stress_phystoken.tok",
+            "stress_phystoken_dos.tok",
+        ],
+    )
     def test_stress(self, fname: str) -> None:
         # Check the tokenization of the stress-test files.
         # And check that those files haven't been incorrectly "fixed".
@@ -109,16 +152,42 @@ class PhysTokensTest(CoverageTest):
 
             stress = os.path.join(TESTS_DIR, fname)
             self.check_file_tokenization(stress)
-            with open(stress) as fstress:
+            with open(stress, encoding="utf-8") as fstress:
                 assert re.search(r"(?m) $", fstress.read()), f"{stress} needs a trailing space."
 
+    def test_fstring_middle(self) -> None:
+        tokens = list(
+            source_token_lines(
+                textwrap.dedent("""\
+            f'Look: {x} {{x}}!'
+            """)
+            )
+        )
+        if env.PYBEHAVIOR.fstring_syntax:
+            assert tokens == [
+                [
+                    ("fst", "f'"),
+                    ("fst", "Look: "),
+                    ("op", "{"),
+                    ("nam", "x"),
+                    ("op", "}"),
+                    ("fst", " {{"),
+                    ("fst", "x}}"),
+                    ("fst", "!"),
+                    ("fst", "'"),
+                ],
+            ]
+        else:
+            assert tokens == [[("str", "f'Look: {x} {{x}}!'")]]
+
+
 @pytest.mark.skipif(not env.PYBEHAVIOR.soft_keywords, reason="Soft keywords are new in Python 3.10")
 class SoftKeywordTest(CoverageTest):
     """Tests the tokenizer handling soft keywords."""
 
     run_in_temp_dir = False
 
-    def test_soft_keywords(self) -> None:
+    def test_soft_keywords_match_case(self) -> None:
         source = textwrap.dedent("""\
             match re.match(something):
                 case ["what"]:
@@ -147,6 +216,16 @@ class SoftKeywordTest(CoverageTest):
         assert tokens[10][2] == ("nam", "match")
         assert tokens[11][3] == ("nam", "case")
 
+    @pytest.mark.skipif(sys.version_info < (3, 12), reason="type isn't a soft keyword until 3.12")
+    def test_soft_keyword_type(self) -> None:
+        source = textwrap.dedent("""\
+            type Point = tuple[float, float]
+            type(int)
+            """)
+        tokens = list(source_token_lines(source))
+        assert tokens[0][0] == ("key", "type")
+        assert tokens[1][0] == ("nam", "type")
+
 
 # The default source file encoding.
 DEF_ENCODING = "utf-8"
@@ -165,6 +244,7 @@ ENCODING_DECLARATION_SOURCES = [
     (2, b"# -*-  coding:cp850 -*-\n# vim: fileencoding=cp850\n", "cp850"),
 ]
 
+
 class SourceEncodingTest(CoverageTest):
     """Tests of source_encoding() for detecting encodings."""
 
@@ -176,7 +256,7 @@ class SourceEncodingTest(CoverageTest):
 
     def test_detect_source_encoding_not_in_comment(self) -> None:
         # Should not detect anything here
-        source = b'def parse(src, encoding=None):\n    pass'
+        source = b"def parse(src, encoding=None):\n    pass"
         assert source_encoding(source) == DEF_ENCODING
 
     def test_dont_detect_source_encoding_on_third_line(self) -> None:
@@ -190,16 +270,16 @@ class SourceEncodingTest(CoverageTest):
 
     def test_bom(self) -> None:
         # A BOM means utf-8.
-        source = b"\xEF\xBB\xBFtext = 'hello'\n"
-        assert source_encoding(source) == 'utf-8-sig'
+        source = b"\xef\xbb\xbftext = 'hello'\n"
+        assert source_encoding(source) == "utf-8-sig"
 
     def test_bom_with_encoding(self) -> None:
-        source = b"\xEF\xBB\xBF# coding: utf-8\ntext = 'hello'\n"
-        assert source_encoding(source) == 'utf-8-sig'
+        source = b"\xef\xbb\xbf# coding: utf-8\ntext = 'hello'\n"
+        assert source_encoding(source) == "utf-8-sig"
 
     def test_bom_is_wrong(self) -> None:
         # A BOM with an explicit non-utf8 encoding is an error.
-        source = b"\xEF\xBB\xBF# coding: cp850\n"
+        source = b"\xef\xbb\xbf# coding: cp850\n"
         with pytest.raises(SyntaxError, match="encoding problem: utf-8"):
             source_encoding(source)
 
